Adaptively round numerics
Arguments
- x
A numeric vector.
- large_threshold
A single number for the threshold over which numbers are to be considered 'large'.
- small_sigfig
A single number for the number of significant digits for 'small' numbers.
- large_digits
A single number for the number of places to which 'large' numbers should be rounded.